summaryrefslogtreecommitdiff
path: root/tools/lli
diff options
context:
space:
mode:
authorGabor Greif <ggreif@gmail.com>2007-07-05 17:07:56 +0000
committerGabor Greif <ggreif@gmail.com>2007-07-05 17:07:56 +0000
commita99be51bf5cdac1438069d4b01766c47704961c8 (patch)
treec743819ee5ce71fc3aa76ed445ca89201b4daf4a /tools/lli
parentf8ad9552215503f7573b5049567ed59c37cc9636 (diff)
downloadllvm-a99be51bf5cdac1438069d4b01766c47704961c8.tar.gz
llvm-a99be51bf5cdac1438069d4b01766c47704961c8.tar.bz2
llvm-a99be51bf5cdac1438069d4b01766c47704961c8.tar.xz
Here is the bulk of the sanitizing.
Almost all occurrences of "bytecode" in the sources have been eliminated. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@37913 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'tools/lli')
-rw-r--r--tools/lli/lli.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/lli/lli.cpp b/tools/lli/lli.cpp
index fdb5f4aa39..3ce28077ae 100644
--- a/tools/lli/lli.cpp
+++ b/tools/lli/lli.cpp
@@ -33,7 +33,7 @@ using namespace llvm;
namespace {
cl::opt<std::string>
- InputFile(cl::desc("<input bytecode>"), cl::Positional, cl::init("-"));
+ InputFile(cl::desc("<input bitcode>"), cl::Positional, cl::init("-"));
cl::list<std::string>
InputArgv(cl::ConsumeAfter, cl::desc("<program arguments>..."));
@@ -74,7 +74,7 @@ int main(int argc, char **argv, char * const *envp) {
if (DisableCoreFiles)
sys::Process::PreventCoreFiles();
// Load the bytecode...
std::string ErrorMsg;
ModuleProvider *MP = 0;
if (MemoryBuffer *Buffer = MemoryBuffer::getFileOrSTDIN(InputFile,&ErrorMsg)){
@@ -74,7 +74,7 @@ int main(int argc, char **argv, char * const *envp) {
if (DisableCoreFiles)
sys::Process::PreventCoreFiles();
- // Load the bytecode...
+ // Load the bitcode...
std::string ErrorMsg;
ModuleProvider *MP = 0;